==> nextcloud-22.2.9.tgz: nextcloud/apps/text/l10n/id.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Berkas teks baru",
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "No file uploaded or file size exceeds maximum of %s" : "Gagal unggah berkas atau ukuran melampaui batas maksimum %s",
    "File could not be loaded. Please check your internet connection." : "Berkas tidak dapat dimuat. Periksa koneksi internet Anda.",
    "Saving …" : "Menyimpan ...",
    "Saved" : "Disimpan",
    "Last saved {lastSaved}" : "Terakhir disimpan {lastSaved}",
    "Edit guest name" : "Edit nama tamu",
    "Guest" : "Tamu",
    "Save guest name" : "Simpan nama tamu",
    "Formatting help" : "Bantuan pemformatan",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "guest" : "pengunjung",
    "Add notes, lists or links …" : "Tambahkan catatan, daftar, atau tautan...",
    "Undo" : "Undo",
    "Info" : "Info",
    "Warning" : "Peringatan",
    "Edit" : "Sunting",
    "Enter your name so other users can see who is editing" : "Tuliskan nama Anda, agar pengguna lain dapat melihat siapa yang sedang mengedit"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.5.tgz: nextcloud/apps/text/l10n/id.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Berkas teks baru",
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "No file uploaded or file size exceeds maximum of %s" : "Gagal unggah berkas atau ukuran melampaui batas maksimum %s",
    "File could not be loaded. Please check your internet connection." : "Berkas tidak dapat dimuat. Periksa koneksi internet Anda.",
    "Saving …" : "Menyimpan ...",
    "Saved" : "Disimpan",
    "Last saved {lastSaved}" : "Terakhir disimpan {lastSaved}",
    "Enter your name so other users can see who is editing" : "Tuliskan nama Anda, agar pengguna lain dapat melihat siapa yang sedang mengedit",
    "Edit guest name" : "Edit nama tamu",
    "Save guest name" : "Simpan nama tamu",
    "Formatting help" : "Bantuan pemformatan",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Add notes, lists or links …" : "Tambahkan catatan, daftar, atau tautan...",
    "Edit" : "Sunting",
    "Undo" : "Undo",
    "Info" : "Info",
    "Warning" : "Peringatan"
},
"nplurals=1; plural=0;");
